# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/symmetric_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/symmetric_key.proto',
  package='yandex.cloud.kms.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'yandex/cloud/kms/v1/symmetric_key.proto\x12\x13yandex.cloud.kms.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xfa\x04\n\x0cSymmetricKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.kms.v1.SymmetricKey.LabelsEntry\x12\x38\n\x06status\x18\x07 \x01(\x0e\x32(.yandex.cloud.kms.v1.SymmetricKey.Status\x12\x41\n\x0fprimary_version\x18\x08 \x01(\x0b\x32(.yandex.cloud.kms.v1.SymmetricKeyVersion\x12\x42\n\x11\x64\x65\x66\x61ult_algorithm\x18\t \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\nrotated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0frotation_period\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13\x64\x65letion_protection\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\"\x92\x03\n\x13SymmetricKeyVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12?\n\x06status\x18\x03 \x01(\x0e\x32/.yandex.cloud.kms.v1.SymmetricKeyVersion.Status\x12:\n\talgorithm\x18\x04 \x01(\x0e\x32\'.yandex.cloud.kms.v1.SymmetricAlgorithm\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07primary\x18\x06 \x01(\x08\x12.\n\ndestroy_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rhosted_by_hsm\x18\x08 \x01(\x08\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03*q\n\x12SymmetricAlgorithm\x12#\n\x1fSYMMETRIC_ALGORITHM_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41\x45S_128\x10\x01\x12\x0b\n\x07\x41\x45S_192\x10\x02\x12\x0b\n\x07\x41\x45S_256\x10\x03\x12\x0f\n\x0b\x41\x45S_256_HSM\x10\x04\x42V\n\x17yandex.cloud.api.kms.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1;kmsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])

_SYMMETRICALGORITHM = _descriptor.EnumDescriptor(
  name='SymmetricAlgorithm',
  full_name='yandex.cloud.kms.v1.SymmetricAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYMMETRIC_ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES_128', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES_192', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES_256', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES_256_HSM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1171,
  serialized_end=1284,
)
_sym_db.RegisterEnumDescriptor(_SYMMETRICALGORITHM)

SymmetricAlgorithm = enum_type_wrapper.EnumTypeWrapper(_SYMMETRICALGORITHM)
SYMMETRIC_ALGORITHM_UNSPECIFIED = 0
AES_128 = 1
AES_192 = 2
AES_256 = 3
AES_256_HSM = 4


_SYMMETRICKEY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.kms.v1.SymmetricKey.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=692,
  serialized_end=764,
)
_sym_db.RegisterEnumDescriptor(_SYMMETRICKEY_STATUS)

_SYMMETRICKEYVERSION_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED_FOR_DESTRUCTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESTROYED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1079,
  serialized_end=1169,
)
_sym_db.RegisterEnumDescriptor(_SYMMETRICKEYVERSION_STATUS)


_SYMMETRICKEY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.SymmetricKey.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.SymmetricKey.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.SymmetricKey.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=690,
)

_SYMMETRICKEY = _descriptor.Descriptor(
  name='SymmetricKey',
  full_name='yandex.cloud.kms.v1.SymmetricKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.kms.v1.SymmetricKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.SymmetricKey.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.kms.v1.SymmetricKey.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.SymmetricKey.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.SymmetricKey.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.SymmetricKey.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.SymmetricKey.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_version', full_name='yandex.cloud.kms.v1.SymmetricKey.primary_version', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_algorithm', full_name='yandex.cloud.kms.v1.SymmetricKey.default_algorithm', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotated_at', full_name='yandex.cloud.kms.v1.SymmetricKey.rotated_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_period', full_name='yandex.cloud.kms.v1.SymmetricKey.rotation_period', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.SymmetricKey.deletion_protection', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SYMMETRICKEY_LABELSENTRY, ],
  enum_types=[
    _SYMMETRICKEY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=764,
)


_SYMMETRICKEYVERSION = _descriptor.Descriptor(
  name='SymmetricKeyVersion',
  full_name='yandex.cloud.kms.v1.SymmetricKeyVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.key_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.algorithm', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.created_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.primary', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destroy_at', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.destroy_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosted_by_hsm', full_name='yandex.cloud.kms.v1.SymmetricKeyVersion.hosted_by_hsm', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYMMETRICKEYVERSION_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=1169,
)

_SYMMETRICKEY_LABELSENTRY.containing_type = _SYMMETRICKEY
_SYMMETRICKEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMMETRICKEY.fields_by_name['labels'].message_type = _SYMMETRICKEY_LABELSENTRY
_SYMMETRICKEY.fields_by_name['status'].enum_type = _SYMMETRICKEY_STATUS
_SYMMETRICKEY.fields_by_name['primary_version'].message_type = _SYMMETRICKEYVERSION
_SYMMETRICKEY.fields_by_name['default_algorithm'].enum_type = _SYMMETRICALGORITHM
_SYMMETRICKEY.fields_by_name['rotated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMMETRICKEY.fields_by_name['rotation_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SYMMETRICKEY_STATUS.containing_type = _SYMMETRICKEY
_SYMMETRICKEYVERSION.fields_by_name['status'].enum_type = _SYMMETRICKEYVERSION_STATUS
_SYMMETRICKEYVERSION.fields_by_name['algorithm'].enum_type = _SYMMETRICALGORITHM
_SYMMETRICKEYVERSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMMETRICKEYVERSION.fields_by_name['destroy_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SYMMETRICKEYVERSION_STATUS.containing_type = _SYMMETRICKEYVERSION
DESCRIPTOR.message_types_by_name['SymmetricKey'] = _SYMMETRICKEY
DESCRIPTOR.message_types_by_name['SymmetricKeyVersion'] = _SYMMETRICKEYVERSION
DESCRIPTOR.enum_types_by_name['SymmetricAlgorithm'] = _SYMMETRICALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SymmetricKey = _reflection.GeneratedProtocolMessageType('SymmetricKey', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SYMMETRICKEY_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.symmetric_key_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.SymmetricKey.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SYMMETRICKEY,
  '__module__' : 'yandex.cloud.kms.v1.symmetric_key_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.SymmetricKey)
  })
_sym_db.RegisterMessage(SymmetricKey)
_sym_db.RegisterMessage(SymmetricKey.LabelsEntry)

SymmetricKeyVersion = _reflection.GeneratedProtocolMessageType('SymmetricKeyVersion', (_message.Message,), {
  'DESCRIPTOR' : _SYMMETRICKEYVERSION,
  '__module__' : 'yandex.cloud.kms.v1.symmetric_key_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.SymmetricKeyVersion)
  })
_sym_db.RegisterMessage(SymmetricKeyVersion)


DESCRIPTOR._options = None
_SYMMETRICKEY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
