# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/app_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/app_token_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/datasphere/v1/app_token_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"(\n\x17\x41ppTokenValidateRequest\x12\r\n\x05token\x18\x01 \x01(\t2\x9e\x01\n\x0f\x41ppTokenService\x12\x8a\x01\n\x08Validate\x12\x33.yandex.cloud.datasphere.v1.AppTokenValidateRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+\")/datasphere/v1/appTokens/{token}:validateBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_APPTOKENVALIDATEREQUEST = _descriptor.Descriptor(
  name='AppTokenValidateRequest',
  full_name='yandex.cloud.datasphere.v1.AppTokenValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='yandex.cloud.datasphere.v1.AppTokenValidateRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=181,
)

DESCRIPTOR.message_types_by_name['AppTokenValidateRequest'] = _APPTOKENVALIDATEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppTokenValidateRequest = _reflection.GeneratedProtocolMessageType('AppTokenValidateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPTOKENVALIDATEREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.app_token_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.AppTokenValidateRequest)
  })
_sym_db.RegisterMessage(AppTokenValidateRequest)


DESCRIPTOR._options = None

_APPTOKENSERVICE = _descriptor.ServiceDescriptor(
  name='AppTokenService',
  full_name='yandex.cloud.datasphere.v1.AppTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=184,
  serialized_end=342,
  methods=[
  _descriptor.MethodDescriptor(
    name='Validate',
    full_name='yandex.cloud.datasphere.v1.AppTokenService.Validate',
    index=0,
    containing_service=None,
    input_type=_APPTOKENVALIDATEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002+\")/datasphere/v1/appTokens/{token}:validate',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APPTOKENSERVICE)

DESCRIPTOR.services_by_name['AppTokenService'] = _APPTOKENSERVICE

# @@protoc_insertion_point(module_scope)
