# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/node_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datasphere/v1/node_service.proto',
  package='yandex.cloud.datasphere.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/datasphere/v1/node_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\"b\n\x14NodeExecutionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12&\n\x05input\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"@\n\x15NodeExecutionResponse\x12\'\n\x06output\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xb1\x01\n\x0bNodeService\x12\xa1\x01\n\x07\x45xecute\x12\x30.yandex.cloud.datasphere.v1.NodeExecutionRequest\x1a\x31.yandex.cloud.datasphere.v1.NodeExecutionResponse\"1\x82\xd3\xe4\x93\x02+\"&/datasphere/v1/nodes/{node_id}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_NODEEXECUTIONREQUEST = _descriptor.Descriptor(
  name='NodeExecutionRequest',
  full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.node_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='yandex.cloud.datasphere.v1.NodeExecutionRequest.input', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=235,
)


_NODEEXECUTIONRESPONSE = _descriptor.Descriptor(
  name='NodeExecutionResponse',
  full_name='yandex.cloud.datasphere.v1.NodeExecutionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='yandex.cloud.datasphere.v1.NodeExecutionResponse.output', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=301,
)

_NODEEXECUTIONREQUEST.fields_by_name['input'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NODEEXECUTIONRESPONSE.fields_by_name['output'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['NodeExecutionRequest'] = _NODEEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name['NodeExecutionResponse'] = _NODEEXECUTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodeExecutionRequest = _reflection.GeneratedProtocolMessageType('NodeExecutionRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEEXECUTIONREQUEST,
  '__module__' : 'yandex.cloud.datasphere.v1.node_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.NodeExecutionRequest)
  })
_sym_db.RegisterMessage(NodeExecutionRequest)

NodeExecutionResponse = _reflection.GeneratedProtocolMessageType('NodeExecutionResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEEXECUTIONRESPONSE,
  '__module__' : 'yandex.cloud.datasphere.v1.node_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datasphere.v1.NodeExecutionResponse)
  })
_sym_db.RegisterMessage(NodeExecutionResponse)


DESCRIPTOR._options = None

_NODESERVICE = _descriptor.ServiceDescriptor(
  name='NodeService',
  full_name='yandex.cloud.datasphere.v1.NodeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=304,
  serialized_end=481,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='yandex.cloud.datasphere.v1.NodeService.Execute',
    index=0,
    containing_service=None,
    input_type=_NODEEXECUTIONREQUEST,
    output_type=_NODEEXECUTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002+\"&/datasphere/v1/nodes/{node_id}:execute:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODESERVICE)

DESCRIPTOR.services_by_name['NodeService'] = _NODESERVICE

# @@protoc_insertion_point(module_scope)
