# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/virtual_host_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import virtual_host_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/virtual_host_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/apploadbalancer/v1/virtual_host_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/apploadbalancer/v1/virtual_host.proto\x1a\x1dyandex/cloud/validation.proto\"|\n\x15GetVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"u\n\x17ListVirtualHostsRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"x\n\x18ListVirtualHostsResponse\x12\x43\n\rvirtual_hosts\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.VirtualHost\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe4\x02\n\x18\x43reateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x11\n\tauthority\x18\x03 \x03(\t\x12\x36\n\x06routes\x18\x05 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\"T\n\x19\x43reateVirtualHostMetadata\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x80\x03\n\x18UpdateVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tauthority\x18\x04 \x03(\t\x12\x36\n\x06routes\x18\x06 \x03(\x0b\x32&.yandex.cloud.apploadbalancer.v1.Route\x12S\n\x16modify_request_headers\x18\x07 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\x12T\n\x17modify_response_headers\x18\x08 \x03(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.HeaderModification\"N\n\x19UpdateVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"\x7f\n\x18\x44\x65leteVirtualHostRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x11virtual_host_name\x18\x02 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\"N\n\x19\x44\x65leteVirtualHostMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\"m\n\x12RemoveRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"\\\n\x13RemoveRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t\"\xa5\x02\n\x12UpdateRouteRequest\x12\x1c\n\x0ehttp_router_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11virtual_host_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nroute_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12:\n\x04http\x18\x05 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.HttpRouteH\x00\x12:\n\x04grpc\x18\x06 \x01(\x0b\x32*.yandex.cloud.apploadbalancer.v1.GrpcRouteH\x00\x42\r\n\x05route\x12\x04\xc0\xc1\x31\x01\"\\\n\x13UpdateRouteMetadata\x12\x16\n\x0ehttp_router_id\x18\x01 \x01(\t\x12\x19\n\x11virtual_host_name\x18\x02 \x01(\t\x12\x12\n\nroute_name\x18\x03 \x01(\t2\xe2\x0c\n\x12VirtualHostService\x12\xc6\x01\n\x03Get\x12\x36.yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest\x1a,.yandex.cloud.apploadbalancer.v1.VirtualHost\"Y\x82\xd3\xe4\x93\x02S\x12Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\x12\xc2\x01\n\x04List\x12\x38.yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest\x1a\x39.yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts\x12\xdc\x01\n\x06\x43reate\x12\x39.yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"t\x82\xd3\xe4\x93\x02\x42\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\x01*\xb2\xd2*(\n\x19\x43reateVirtualHostMetadata\x12\x0bVirtualHost\x12\xf1\x01\n\x06Update\x12\x39.yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\x01*\xb2\xd2*(\n\x19UpdateVirtualHostMetadata\x12\x0bVirtualHost\x12\xf8\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\x82\xd3\xe4\x93\x02S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\xb2\xd2*2\n\x19\x44\x65leteVirtualHostMetadata\x12\x15google.protobuf.Empty\x12\xf6\x01\n\x0bRemoveRoute\x12\x33.yandex.cloud.apploadbalancer.v1.RemoveRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\x01*\xb2\xd2*\"\n\x13RemoveRouteMetadata\x12\x0bVirtualHost\x12\xf6\x01\n\x0bUpdateRoute\x12\x33.yandex.cloud.apploadbalancer.v1.UpdateRouteRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02\x62\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\x01*\xb2\xd2*\"\n\x13UpdateRouteMetadata\x12\x0bVirtualHostBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='GetVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=440,
)


_LISTVIRTUALHOSTSREQUEST = _descriptor.Descriptor(
  name='ListVirtualHostsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=442,
  serialized_end=559,
)


_LISTVIRTUALHOSTSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualHostsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse.virtual_hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=681,
)


_CREATEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='CreateVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.authority', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.routes', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_request_headers', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.modify_request_headers', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_response_headers', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest.modify_response_headers', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=1040,
)


_CREATEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='CreateVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1126,
)


_UPDATEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.authority', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.routes', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_request_headers', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.modify_request_headers', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modify_response_headers', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest.modify_response_headers', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1513,
)


_UPDATEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='UpdateVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1593,
)


_DELETEVIRTUALHOSTREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualHostRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1595,
  serialized_end=1722,
)


_DELETEVIRTUALHOSTMETADATA = _descriptor.Descriptor(
  name='DeleteVirtualHostMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1802,
)


_REMOVEROUTEREQUEST = _descriptor.Descriptor(
  name='RemoveRouteRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteRequest.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1913,
)


_REMOVEROUTEMETADATA = _descriptor.Descriptor(
  name='RemoveRouteMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2007,
)


_UPDATEROUTEREQUEST = _descriptor.Descriptor(
  name='UpdateRouteRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.update_mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.http', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.grpc', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteRequest.route',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2010,
  serialized_end=2303,
)


_UPDATEROUTEMETADATA = _descriptor.Descriptor(
  name='UpdateRouteMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_router_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.http_router_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_host_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.virtual_host_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata.route_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2305,
  serialized_end=2397,
)

_LISTVIRTUALHOSTSRESPONSE.fields_by_name['virtual_hosts'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST
_CREATEVIRTUALHOSTREQUEST.fields_by_name['routes'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTE
_CREATEVIRTUALHOSTREQUEST.fields_by_name['modify_request_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_CREATEVIRTUALHOSTREQUEST.fields_by_name['modify_response_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['routes'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._ROUTE
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['modify_request_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['modify_response_headers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HEADERMODIFICATION
_UPDATEROUTEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEROUTEREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._HTTPROUTE
_UPDATEROUTEREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._GRPCROUTE
_UPDATEROUTEREQUEST.oneofs_by_name['route'].fields.append(
  _UPDATEROUTEREQUEST.fields_by_name['http'])
_UPDATEROUTEREQUEST.fields_by_name['http'].containing_oneof = _UPDATEROUTEREQUEST.oneofs_by_name['route']
_UPDATEROUTEREQUEST.oneofs_by_name['route'].fields.append(
  _UPDATEROUTEREQUEST.fields_by_name['grpc'])
_UPDATEROUTEREQUEST.fields_by_name['grpc'].containing_oneof = _UPDATEROUTEREQUEST.oneofs_by_name['route']
DESCRIPTOR.message_types_by_name['GetVirtualHostRequest'] = _GETVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualHostsRequest'] = _LISTVIRTUALHOSTSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualHostsResponse'] = _LISTVIRTUALHOSTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualHostRequest'] = _CREATEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualHostMetadata'] = _CREATEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['UpdateVirtualHostRequest'] = _UPDATEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualHostMetadata'] = _UPDATEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['DeleteVirtualHostRequest'] = _DELETEVIRTUALHOSTREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualHostMetadata'] = _DELETEVIRTUALHOSTMETADATA
DESCRIPTOR.message_types_by_name['RemoveRouteRequest'] = _REMOVEROUTEREQUEST
DESCRIPTOR.message_types_by_name['RemoveRouteMetadata'] = _REMOVEROUTEMETADATA
DESCRIPTOR.message_types_by_name['UpdateRouteRequest'] = _UPDATEROUTEREQUEST
DESCRIPTOR.message_types_by_name['UpdateRouteMetadata'] = _UPDATEROUTEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetVirtualHostRequest = _reflection.GeneratedProtocolMessageType('GetVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetVirtualHostRequest)
  })
_sym_db.RegisterMessage(GetVirtualHostRequest)

ListVirtualHostsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualHostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALHOSTSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListVirtualHostsRequest)
  })
_sym_db.RegisterMessage(ListVirtualHostsRequest)

ListVirtualHostsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualHostsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALHOSTSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListVirtualHostsResponse)
  })
_sym_db.RegisterMessage(ListVirtualHostsResponse)

CreateVirtualHostRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateVirtualHostRequest)
  })
_sym_db.RegisterMessage(CreateVirtualHostRequest)

CreateVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('CreateVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateVirtualHostMetadata)
  })
_sym_db.RegisterMessage(CreateVirtualHostMetadata)

UpdateVirtualHostRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateVirtualHostRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualHostRequest)

UpdateVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('UpdateVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateVirtualHostMetadata)
  })
_sym_db.RegisterMessage(UpdateVirtualHostMetadata)

DeleteVirtualHostRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualHostRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALHOSTREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteVirtualHostRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualHostRequest)

DeleteVirtualHostMetadata = _reflection.GeneratedProtocolMessageType('DeleteVirtualHostMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALHOSTMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteVirtualHostMetadata)
  })
_sym_db.RegisterMessage(DeleteVirtualHostMetadata)

RemoveRouteRequest = _reflection.GeneratedProtocolMessageType('RemoveRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROUTEREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveRouteRequest)
  })
_sym_db.RegisterMessage(RemoveRouteRequest)

RemoveRouteMetadata = _reflection.GeneratedProtocolMessageType('RemoveRouteMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEROUTEMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveRouteMetadata)
  })
_sym_db.RegisterMessage(RemoveRouteMetadata)

UpdateRouteRequest = _reflection.GeneratedProtocolMessageType('UpdateRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROUTEREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateRouteRequest)
  })
_sym_db.RegisterMessage(UpdateRouteRequest)

UpdateRouteMetadata = _reflection.GeneratedProtocolMessageType('UpdateRouteMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROUTEMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateRouteMetadata)
  })
_sym_db.RegisterMessage(UpdateRouteMetadata)


DESCRIPTOR._options = None
_GETVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_GETVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['http_router_id']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['page_size']._options = None
_LISTVIRTUALHOSTSREQUEST.fields_by_name['page_token']._options = None
_CREATEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_CREATEVIRTUALHOSTREQUEST.fields_by_name['name']._options = None
_CREATEVIRTUALHOSTMETADATA.fields_by_name['http_router_id']._options = None
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_DELETEVIRTUALHOSTREQUEST.fields_by_name['http_router_id']._options = None
_DELETEVIRTUALHOSTREQUEST.fields_by_name['virtual_host_name']._options = None
_REMOVEROUTEREQUEST.fields_by_name['http_router_id']._options = None
_REMOVEROUTEREQUEST.fields_by_name['virtual_host_name']._options = None
_REMOVEROUTEREQUEST.fields_by_name['route_name']._options = None
_UPDATEROUTEREQUEST.oneofs_by_name['route']._options = None
_UPDATEROUTEREQUEST.fields_by_name['http_router_id']._options = None
_UPDATEROUTEREQUEST.fields_by_name['virtual_host_name']._options = None
_UPDATEROUTEREQUEST.fields_by_name['route_name']._options = None

_VIRTUALHOSTSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualHostService',
  full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2400,
  serialized_end=4034,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Get',
    index=0,
    containing_service=None,
    input_type=_GETVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_virtual__host__pb2._VIRTUALHOST,
    serialized_options=b'\202\323\344\223\002S\022Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.List',
    index=1,
    containing_service=None,
    input_type=_LISTVIRTUALHOSTSREQUEST,
    output_type=_LISTVIRTUALHOSTSRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002B\"=/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts:\001*\262\322*(\n\031CreateVirtualHostMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002V2Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:\001*\262\322*(\n\031UpdateVirtualHostMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEVIRTUALHOSTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002S*Q/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}\262\322*2\n\031DeleteVirtualHostMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveRoute',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.RemoveRoute',
    index=5,
    containing_service=None,
    input_type=_REMOVEROUTEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:removeRoute:\001*\262\322*\"\n\023RemoveRouteMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRoute',
    full_name='yandex.cloud.apploadbalancer.v1.VirtualHostService.UpdateRoute',
    index=6,
    containing_service=None,
    input_type=_UPDATEROUTEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002b\"]/apploadbalancer/v1/httpRouters/{http_router_id}/virtualHosts/{virtual_host_name}:updateRoute:\001*\262\322*\"\n\023UpdateRouteMetadata\022\013VirtualHost',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALHOSTSERVICE)

DESCRIPTOR.services_by_name['VirtualHostService'] = _VIRTUALHOSTSERVICE

# @@protoc_insertion_point(module_scope)
